var _Item, _Item2, _Item3, _Item4, _Item5, _Item6, _Item7, _Item8, _Item9, _Item10, _Item11, _Item12;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

import { render, screen, waitFor } from '@testing-library/react';
import { vi, expect } from 'vitest';
import userEvent from '@testing-library/user-event';
import '@testing-library/jest-dom';
import { IconCheckSolid } from '@instructure/ui-icons';
import { Options } from '../../index';
import { Item } from '../index';
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
describe('<Item />', () => {
  it('should render', async () => {
    const _render = render(_Item || (_Item = _jsx(Item, {}))),
      container = _render.container;
    const optionItem = container.querySelector('[class$="-optionItem"]');
    expect(optionItem).toBeInTheDocument();
    const optionItemContainer = optionItem.querySelector('[class$="-optionItem__container"]');
    expect(optionItemContainer).toBeInTheDocument();
  });
  it('should not render as a list item by default', async () => {
    const _render2 = render(_Item2 || (_Item2 = _jsx(Item, {
        children: "Hello World"
      }))),
      container = _render2.container;
    const item = container.querySelector('[class$="-optionItem"]');
    expect(item).toBeInTheDocument();
    expect(item.tagName).not.toBe('LI');
  });
  it('should render designated tag if `as` prop is specified', async () => {
    const _render3 = render(_Item3 || (_Item3 = _jsx(Item, {
        as: "li",
        children: "Hello World"
      }))),
      container = _render3.container;
    const item = container.querySelector('[class$="-optionItem"]');
    expect(item).toBeInTheDocument();
    expect(item.tagName).toBe('LI');
  });
  it('should render children properly', async () => {
    const _render4 = render(_Item4 || (_Item4 = _jsx(Item, {
        children: _jsx("span", {
          id: "customContent",
          children: "Hello World"
        })
      }))),
      container = _render4.container;
    const item = container.querySelector('[class$="-optionItem"]');
    const customContent = item.querySelector('#customContent');
    expect(customContent).toHaveTextContent('Hello World');
  });
  it('should render role attributes appropriately when given a role', async () => {
    const _render5 = render(_Item5 || (_Item5 = _jsx(Item, {
        role: "option",
        children: "Hello World"
      }))),
      container = _render5.container;
    const item = container.querySelector('[class$="-optionItem"]');
    const child = screen.getByRole('option');
    expect(item).toHaveAttribute('role', 'none');
    expect(child).toBeInTheDocument();
  });
  it('should render description properly', async () => {
    const _render6 = render(_Item6 || (_Item6 = _jsx(Item, {
        description: "Some text as description",
        children: _jsx("span", {
          id: "customContent",
          children: "Hello World"
        })
      }))),
      container = _render6.container;
    const item = container.querySelector('[class$="-optionItem"]');
    const customContent = item.querySelector('#customContent');
    const description = item.querySelector('[class$="__description"]');
    expect(customContent).toHaveTextContent('Hello World');
    expect(description).toHaveTextContent('Some text as description');
  });
  it('should render role attributes for description', async () => {
    render(_Item7 || (_Item7 = _jsx(Item, {
      description: "Some text as description",
      descriptionRole: "comment",
      children: "Hello World"
    })));
    const description = screen.getByRole('comment');
    expect(description).toBeInTheDocument();
    expect(description).toHaveTextContent('Some text as description');
  });
  it('should pass props through to label', async () => {
    const _render7 = render(_Item8 || (_Item8 = _jsx(Item, {
        role: "option",
        tabIndex: -1,
        "data-custom-attr": "true",
        children: "Hello World"
      }))),
      container = _render7.container;
    const optionItem = container.querySelector('[class$="-optionItem"]');
    const optionItemContainer = optionItem.querySelector('[class$="-optionItem__container"]');
    expect(optionItem).toHaveRole('none');
    expect(optionItemContainer).toHaveRole('option');
    expect(optionItemContainer).toHaveAttribute('tabindex', '-1');
    expect(optionItemContainer).toHaveAttribute('data-custom-attr', 'true');
  });
  it('should pass event handlers through to label', async () => {
    const onClick = vi.fn();
    const _render8 = render(_jsx(Item, {
        onClick: onClick,
        children: "Hello World"
      })),
      container = _render8.container;
    const optionItem = container.querySelector('[class$="-optionItem"]');
    const optionItemContainer = container.querySelector('[class$="-optionItem__container"]');
    userEvent.click(optionItem);
    await waitFor(() => {
      expect(onClick).not.toHaveBeenCalled();
    });
    userEvent.click(optionItemContainer);
    await waitFor(() => {
      expect(onClick).toHaveBeenCalledTimes(1);
    });
  });
  it('should render content before label', async () => {
    const _render9 = render(_Item9 || (_Item9 = _jsx(Item, {
        renderBeforeLabel: _jsx(IconCheckSolid, {}),
        children: "Hello World"
      }))),
      container = _render9.container;
    const content = container.querySelector('[class$=-optionItem__content--before]');
    expect(content).toBeInTheDocument();
    const icon = content.querySelector('svg[name="IconCheck"]');
    expect(icon).toBeInTheDocument();
  });
  it('should render content after label', async () => {
    const _render10 = render(_Item10 || (_Item10 = _jsx(Item, {
        renderAfterLabel: _jsx(IconCheckSolid, {}),
        children: "Hello World"
      }))),
      container = _render10.container;
    const content = container.querySelector('[class$=-optionItem__content--after]');
    expect(content).toBeInTheDocument();
    const icon = content.querySelector('svg[name="IconCheck"]');
    expect(icon).toBeInTheDocument();
  });
  it('should render nested lists', async () => {
    const _render11 = render(_Item11 || (_Item11 = _jsx(Item, {
        children: _jsx(Options, {
          as: "ul",
          renderLabel: 'Nested list',
          children: _jsx(Item, {
            children: "Sub item"
          })
        })
      }))),
      container = _render11.container;
    const item = container.querySelector('span[class$="-optionItem"]');
    expect(item).toBeInTheDocument();
    const options = item.querySelector('div[class$="-options"]');
    expect(options).toBeInTheDocument();
    const nestedList = options.querySelector('ul');
    const nestedItem = options.querySelector('li[class$="-optionItem"]');
    expect(nestedList).toBeInTheDocument();
    expect(nestedItem).toBeInTheDocument();
    expect(nestedItem).toHaveTextContent('Sub item');
  });
  it('should render as link with href prop', async () => {
    const _render12 = render(_Item12 || (_Item12 = _jsx(Item, {
        href: "/helloWorld",
        children: "Hello World"
      }))),
      container = _render12.container;
    const link = container.querySelector('[class$="-optionItem__container"]');
    expect(link).toBeInTheDocument();
    expect(link).toHaveAttribute('href', '/helloWorld');
    expect(link === null || link === void 0 ? void 0 : link.tagName).toBe('A');
  });
});