var _Options, _Options2, _Options$Item, _Options$Item2, _Options3, _Options4, _Options5, _Options6, _Options7, _Options8, _Options9;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

import { render, screen } from '@testing-library/react';
import { vi, expect } from 'vitest';
import { runAxeCheck } from '@instructure/ui-axe-check';

// eslint-disable-next-line no-restricted-imports
import { generateA11yTests } from '@instructure/ui-scripts/lib/test/generateA11yTests';
import '@testing-library/jest-dom';
import { Options } from '../index';
import OptionsExamples from '../__examples__/Options.examples';
import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
describe('<Options />', () => {
  it('should render', async () => {
    const _render = render(_Options || (_Options = _jsx(Options, {}))),
      container = _render.container;
    const options = container.querySelector('div[class*="-options"]');
    expect(options).toBeInTheDocument();
  });
  it('should render items', async () => {
    render(_Options2 || (_Options2 = _jsxs(Options, {
      children: [_jsx(Options.Item, {
        children: "Option one"
      }), _jsx(Options.Item, {
        children: "Option two"
      })]
    })));
    const items = screen.getAllByRole('listitem');
    expect(items.length).toBe(2);
  });
  it('should provide elementRef', async () => {
    const elementRef = vi.fn();
    render(_jsxs(Options, {
      elementRef: elementRef,
      as: "ul",
      children: [_Options$Item || (_Options$Item = _jsx(Options.Item, {
        children: "Option one"
      })), _Options$Item2 || (_Options$Item2 = _jsx(Options.Item, {
        children: "Option two"
      }))]
    }));
    const optionList = screen.getByRole('list');
    expect(elementRef).toHaveBeenCalledWith(optionList);
  });
  it('should render designated tag if `as` prop is specified', async () => {
    render(_Options3 || (_Options3 = _jsxs(Options, {
      as: "ol",
      children: [_jsx(Options.Item, {
        children: "Option one"
      }), _jsx(Options.Item, {
        children: "Option two"
      })]
    })));
    const optionList = screen.getByRole('list');
    expect(optionList.tagName).toBe('OL');
  });
  it('should render children as listitems when appropriate', async () => {
    const _render2 = render(_Options4 || (_Options4 = _jsxs(Options, {
        as: "ul",
        children: [_jsx(Options.Item, {
          children: "Option one"
        }), _jsx(Options.Item, {
          children: "Option two"
        })]
      }))),
      container = _render2.container;
    const list = container.querySelector('ul');
    const items = container.querySelectorAll('li');
    expect(list).toBeInTheDocument();
    expect(items.length).toBe(2);
  });
  it('should pass props through to list', async () => {
    const _render3 = render(_Options5 || (_Options5 = _jsxs(Options, {
        as: "ul",
        role: "listbox",
        "data-custom-attr": "true",
        children: [_jsx(Options.Item, {
          children: "Option one"
        }), _jsx(Options.Item, {
          children: "Option two"
        })]
      }))),
      container = _render3.container;
    const options = container.querySelector('[class*="-options__list"]');
    expect(options).toHaveRole('listbox');
    expect(options).toHaveAttribute('data-custom-attr', 'true');
  });
  it('should render root with appropriate role', async () => {
    const _render4 = render(_Options6 || (_Options6 = _jsxs(Options, {
        role: "listbox",
        children: [_jsx(Options.Item, {
          children: "Option one"
        }), _jsx(Options.Item, {
          children: "Option two"
        })]
      }))),
      container = _render4.container;
    const options = container.querySelector('div[class*="-options"]');
    expect(options).toHaveAttribute('role', 'presentation');
  });
  it('should allow null children', async () => {
    render(_Options7 || (_Options7 = _jsx(Options, {})));
    const options = screen.getByRole('list');
    expect(options).toBeInTheDocument();
  });
  it('should render nested options properly', async () => {
    const _render5 = render(_Options8 || (_Options8 = _jsxs(Options, {
        "data-testId": "outer-list",
        children: [_jsx(Options.Item, {
          children: "Option one "
        }), _jsx(Options.Item, {
          children: "Option two "
        }), _jsxs(Options, {
          renderLabel: 'Nested list',
          "data-testId": "nested-list",
          children: [_jsx(Options.Item, {
            children: "Nested option one "
          }), _jsx(Options.Item, {
            children: "Nested option two "
          })]
        })]
      }))),
      container = _render5.container;
    const allLists = container.querySelectorAll('[class*="-options__list"]');
    const allItems = container.querySelectorAll('[class$="-optionItem"]');
    expect(allLists.length).toBe(2);
    expect(allItems.length).toBe(5);
    const outerList = screen.getByTestId('outer-list');
    expect(outerList).toHaveTextContent('Option one Option two');
    const nestedLabel = outerList.querySelector('[class*=-options__label]');
    expect(nestedLabel).toBeInTheDocument();
    expect(nestedLabel).toHaveTextContent('Nested list');
    const nestedList = screen.getByTestId('nested-list');
    expect(nestedList).toHaveTextContent('Nested option one Nested option two');
    const nestedListItems = nestedList.querySelectorAll('[class$=-optionItem]');
    expect(nestedListItems.length).toBe(2);
    expect(outerList).toContainElement(nestedLabel);
    expect(outerList).toContainElement(nestedList);
  });
  describe('with generated examples', () => {
    const generatedComponents = generateA11yTests(Options, OptionsExamples);
    for (const component of generatedComponents) {
      it(component.description, async () => {
        const _render6 = render(component.content),
          container = _render6.container;

        // axe-check is more strict now, and expects "list" role to have "listitem" children, but we use "role='none'" children. After discussing it with the A11y team, we agreed to ignore this error because the screen readers can read the component perfectly.
        // TODO: try to remove this ignore if axe-check is updated and isn't this strict anymore
        // https://dequeuniversity.com/rules/axe/4.6/aria-required-children?application=axeAPI
        const axeCheck = await runAxeCheck(container, {
          ignores: ['aria-required-children']
        });
        expect(axeCheck).toBe(true);
      });
    }
  });
  describe('for a11y', () => {
    it('should be accessible with links', async () => {
      const _render7 = render(_Options9 || (_Options9 = _jsxs(Options, {
          children: [_jsx(Options.Item, {
            children: "Option"
          }), _jsx(Options.Item, {
            href: "/",
            children: "Option link"
          })]
        }))),
        container = _render7.container;

      // axe-check is more strict now, and expects "list" role to have "listitem" children, but we use "role='none'" children. After discussing it with the A11y team, we agreed to ignore this error because the screen readers can read the component perfectly.
      // TODO: try to remove this ignore if axe-check is updated and isn't this strict anymore
      // https://dequeuniversity.com/rules/axe/4.6/aria-required-children?application=axeAPI
      const axeCheck = await runAxeCheck(container, {
        ignores: ['aria-required-children']
      });
      expect(axeCheck).toBe(true);
    });
  });
});