"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
var _react = require("@testing-library/react");
var _vitest = require("vitest");
var _userEvent = _interopRequireDefault(require("@testing-library/user-event"));
require("@testing-library/jest-dom");
var _uiIcons = require("@instructure/ui-icons");
var _index = require("../../index");
var _index2 = require("../index");
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _Item, _Item2, _Item3, _Item4, _Item5, _Item6, _Item7, _Item8, _Item9, _Item10, _Item11, _Item12;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
describe('<Item />', () => {
  it('should render', async () => {
    const _render = (0, _react.render)(_Item || (_Item = (0, _jsxRuntime.jsx)(_index2.Item, {}))),
      container = _render.container;
    const optionItem = container.querySelector('[class$="-optionItem"]');
    (0, _vitest.expect)(optionItem).toBeInTheDocument();
    const optionItemContainer = optionItem.querySelector('[class$="-optionItem__container"]');
    (0, _vitest.expect)(optionItemContainer).toBeInTheDocument();
  });
  it('should not render as a list item by default', async () => {
    const _render2 = (0, _react.render)(_Item2 || (_Item2 = (0, _jsxRuntime.jsx)(_index2.Item, {
        children: "Hello World"
      }))),
      container = _render2.container;
    const item = container.querySelector('[class$="-optionItem"]');
    (0, _vitest.expect)(item).toBeInTheDocument();
    (0, _vitest.expect)(item.tagName).not.toBe('LI');
  });
  it('should render designated tag if `as` prop is specified', async () => {
    const _render3 = (0, _react.render)(_Item3 || (_Item3 = (0, _jsxRuntime.jsx)(_index2.Item, {
        as: "li",
        children: "Hello World"
      }))),
      container = _render3.container;
    const item = container.querySelector('[class$="-optionItem"]');
    (0, _vitest.expect)(item).toBeInTheDocument();
    (0, _vitest.expect)(item.tagName).toBe('LI');
  });
  it('should render children properly', async () => {
    const _render4 = (0, _react.render)(_Item4 || (_Item4 = (0, _jsxRuntime.jsx)(_index2.Item, {
        children: (0, _jsxRuntime.jsx)("span", {
          id: "customContent",
          children: "Hello World"
        })
      }))),
      container = _render4.container;
    const item = container.querySelector('[class$="-optionItem"]');
    const customContent = item.querySelector('#customContent');
    (0, _vitest.expect)(customContent).toHaveTextContent('Hello World');
  });
  it('should render role attributes appropriately when given a role', async () => {
    const _render5 = (0, _react.render)(_Item5 || (_Item5 = (0, _jsxRuntime.jsx)(_index2.Item, {
        role: "option",
        children: "Hello World"
      }))),
      container = _render5.container;
    const item = container.querySelector('[class$="-optionItem"]');
    const child = _react.screen.getByRole('option');
    (0, _vitest.expect)(item).toHaveAttribute('role', 'none');
    (0, _vitest.expect)(child).toBeInTheDocument();
  });
  it('should render description properly', async () => {
    const _render6 = (0, _react.render)(_Item6 || (_Item6 = (0, _jsxRuntime.jsx)(_index2.Item, {
        description: "Some text as description",
        children: (0, _jsxRuntime.jsx)("span", {
          id: "customContent",
          children: "Hello World"
        })
      }))),
      container = _render6.container;
    const item = container.querySelector('[class$="-optionItem"]');
    const customContent = item.querySelector('#customContent');
    const description = item.querySelector('[class$="__description"]');
    (0, _vitest.expect)(customContent).toHaveTextContent('Hello World');
    (0, _vitest.expect)(description).toHaveTextContent('Some text as description');
  });
  it('should render role attributes for description', async () => {
    (0, _react.render)(_Item7 || (_Item7 = (0, _jsxRuntime.jsx)(_index2.Item, {
      description: "Some text as description",
      descriptionRole: "comment",
      children: "Hello World"
    })));
    const description = _react.screen.getByRole('comment');
    (0, _vitest.expect)(description).toBeInTheDocument();
    (0, _vitest.expect)(description).toHaveTextContent('Some text as description');
  });
  it('should pass props through to label', async () => {
    const _render7 = (0, _react.render)(_Item8 || (_Item8 = (0, _jsxRuntime.jsx)(_index2.Item, {
        role: "option",
        tabIndex: -1,
        "data-custom-attr": "true",
        children: "Hello World"
      }))),
      container = _render7.container;
    const optionItem = container.querySelector('[class$="-optionItem"]');
    const optionItemContainer = optionItem.querySelector('[class$="-optionItem__container"]');
    (0, _vitest.expect)(optionItem).toHaveRole('none');
    (0, _vitest.expect)(optionItemContainer).toHaveRole('option');
    (0, _vitest.expect)(optionItemContainer).toHaveAttribute('tabindex', '-1');
    (0, _vitest.expect)(optionItemContainer).toHaveAttribute('data-custom-attr', 'true');
  });
  it('should pass event handlers through to label', async () => {
    const onClick = _vitest.vi.fn();
    const _render8 = (0, _react.render)((0, _jsxRuntime.jsx)(_index2.Item, {
        onClick: onClick,
        children: "Hello World"
      })),
      container = _render8.container;
    const optionItem = container.querySelector('[class$="-optionItem"]');
    const optionItemContainer = container.querySelector('[class$="-optionItem__container"]');
    _userEvent.default.click(optionItem);
    await (0, _react.waitFor)(() => {
      (0, _vitest.expect)(onClick).not.toHaveBeenCalled();
    });
    _userEvent.default.click(optionItemContainer);
    await (0, _react.waitFor)(() => {
      (0, _vitest.expect)(onClick).toHaveBeenCalledTimes(1);
    });
  });
  it('should render content before label', async () => {
    const _render9 = (0, _react.render)(_Item9 || (_Item9 = (0, _jsxRuntime.jsx)(_index2.Item, {
        renderBeforeLabel: (0, _jsxRuntime.jsx)(_uiIcons.IconCheckSolid, {}),
        children: "Hello World"
      }))),
      container = _render9.container;
    const content = container.querySelector('[class$=-optionItem__content--before]');
    (0, _vitest.expect)(content).toBeInTheDocument();
    const icon = content.querySelector('svg[name="IconCheck"]');
    (0, _vitest.expect)(icon).toBeInTheDocument();
  });
  it('should render content after label', async () => {
    const _render10 = (0, _react.render)(_Item10 || (_Item10 = (0, _jsxRuntime.jsx)(_index2.Item, {
        renderAfterLabel: (0, _jsxRuntime.jsx)(_uiIcons.IconCheckSolid, {}),
        children: "Hello World"
      }))),
      container = _render10.container;
    const content = container.querySelector('[class$=-optionItem__content--after]');
    (0, _vitest.expect)(content).toBeInTheDocument();
    const icon = content.querySelector('svg[name="IconCheck"]');
    (0, _vitest.expect)(icon).toBeInTheDocument();
  });
  it('should render nested lists', async () => {
    const _render11 = (0, _react.render)(_Item11 || (_Item11 = (0, _jsxRuntime.jsx)(_index2.Item, {
        children: (0, _jsxRuntime.jsx)(_index.Options, {
          as: "ul",
          renderLabel: 'Nested list',
          children: (0, _jsxRuntime.jsx)(_index2.Item, {
            children: "Sub item"
          })
        })
      }))),
      container = _render11.container;
    const item = container.querySelector('span[class$="-optionItem"]');
    (0, _vitest.expect)(item).toBeInTheDocument();
    const options = item.querySelector('div[class$="-options"]');
    (0, _vitest.expect)(options).toBeInTheDocument();
    const nestedList = options.querySelector('ul');
    const nestedItem = options.querySelector('li[class$="-optionItem"]');
    (0, _vitest.expect)(nestedList).toBeInTheDocument();
    (0, _vitest.expect)(nestedItem).toBeInTheDocument();
    (0, _vitest.expect)(nestedItem).toHaveTextContent('Sub item');
  });
  it('should render as link with href prop', async () => {
    const _render12 = (0, _react.render)(_Item12 || (_Item12 = (0, _jsxRuntime.jsx)(_index2.Item, {
        href: "/helloWorld",
        children: "Hello World"
      }))),
      container = _render12.container;
    const link = container.querySelector('[class$="-optionItem__container"]');
    (0, _vitest.expect)(link).toBeInTheDocument();
    (0, _vitest.expect)(link).toHaveAttribute('href', '/helloWorld');
    (0, _vitest.expect)(link === null || link === void 0 ? void 0 : link.tagName).toBe('A');
  });
});