"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
var _react = require("@testing-library/react");
var _vitest = require("vitest");
var _uiAxeCheck = require("@instructure/ui-axe-check");
var _generateA11yTests = require("@instructure/ui-scripts/lib/test/generateA11yTests");
require("@testing-library/jest-dom");
var _index = require("../index");
var _Options10 = _interopRequireDefault(require("../__examples__/Options.examples"));
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _Options, _Options2, _Options$Item, _Options$Item2, _Options3, _Options4, _Options5, _Options6, _Options7, _Options8, _Options9;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
// eslint-disable-next-line no-restricted-imports
describe('<Options />', () => {
  it('should render', async () => {
    const _render = (0, _react.render)(_Options || (_Options = (0, _jsxRuntime.jsx)(_index.Options, {}))),
      container = _render.container;
    const options = container.querySelector('div[class*="-options"]');
    (0, _vitest.expect)(options).toBeInTheDocument();
  });
  it('should render items', async () => {
    (0, _react.render)(_Options2 || (_Options2 = (0, _jsxRuntime.jsxs)(_index.Options, {
      children: [(0, _jsxRuntime.jsx)(_index.Options.Item, {
        children: "Option one"
      }), (0, _jsxRuntime.jsx)(_index.Options.Item, {
        children: "Option two"
      })]
    })));
    const items = _react.screen.getAllByRole('listitem');
    (0, _vitest.expect)(items.length).toBe(2);
  });
  it('should provide elementRef', async () => {
    const elementRef = _vitest.vi.fn();
    (0, _react.render)((0, _jsxRuntime.jsxs)(_index.Options, {
      elementRef: elementRef,
      as: "ul",
      children: [_Options$Item || (_Options$Item = (0, _jsxRuntime.jsx)(_index.Options.Item, {
        children: "Option one"
      })), _Options$Item2 || (_Options$Item2 = (0, _jsxRuntime.jsx)(_index.Options.Item, {
        children: "Option two"
      }))]
    }));
    const optionList = _react.screen.getByRole('list');
    (0, _vitest.expect)(elementRef).toHaveBeenCalledWith(optionList);
  });
  it('should render designated tag if `as` prop is specified', async () => {
    (0, _react.render)(_Options3 || (_Options3 = (0, _jsxRuntime.jsxs)(_index.Options, {
      as: "ol",
      children: [(0, _jsxRuntime.jsx)(_index.Options.Item, {
        children: "Option one"
      }), (0, _jsxRuntime.jsx)(_index.Options.Item, {
        children: "Option two"
      })]
    })));
    const optionList = _react.screen.getByRole('list');
    (0, _vitest.expect)(optionList.tagName).toBe('OL');
  });
  it('should render children as listitems when appropriate', async () => {
    const _render2 = (0, _react.render)(_Options4 || (_Options4 = (0, _jsxRuntime.jsxs)(_index.Options, {
        as: "ul",
        children: [(0, _jsxRuntime.jsx)(_index.Options.Item, {
          children: "Option one"
        }), (0, _jsxRuntime.jsx)(_index.Options.Item, {
          children: "Option two"
        })]
      }))),
      container = _render2.container;
    const list = container.querySelector('ul');
    const items = container.querySelectorAll('li');
    (0, _vitest.expect)(list).toBeInTheDocument();
    (0, _vitest.expect)(items.length).toBe(2);
  });
  it('should pass props through to list', async () => {
    const _render3 = (0, _react.render)(_Options5 || (_Options5 = (0, _jsxRuntime.jsxs)(_index.Options, {
        as: "ul",
        role: "listbox",
        "data-custom-attr": "true",
        children: [(0, _jsxRuntime.jsx)(_index.Options.Item, {
          children: "Option one"
        }), (0, _jsxRuntime.jsx)(_index.Options.Item, {
          children: "Option two"
        })]
      }))),
      container = _render3.container;
    const options = container.querySelector('[class*="-options__list"]');
    (0, _vitest.expect)(options).toHaveRole('listbox');
    (0, _vitest.expect)(options).toHaveAttribute('data-custom-attr', 'true');
  });
  it('should render root with appropriate role', async () => {
    const _render4 = (0, _react.render)(_Options6 || (_Options6 = (0, _jsxRuntime.jsxs)(_index.Options, {
        role: "listbox",
        children: [(0, _jsxRuntime.jsx)(_index.Options.Item, {
          children: "Option one"
        }), (0, _jsxRuntime.jsx)(_index.Options.Item, {
          children: "Option two"
        })]
      }))),
      container = _render4.container;
    const options = container.querySelector('div[class*="-options"]');
    (0, _vitest.expect)(options).toHaveAttribute('role', 'presentation');
  });
  it('should allow null children', async () => {
    (0, _react.render)(_Options7 || (_Options7 = (0, _jsxRuntime.jsx)(_index.Options, {})));
    const options = _react.screen.getByRole('list');
    (0, _vitest.expect)(options).toBeInTheDocument();
  });
  it('should render nested options properly', async () => {
    const _render5 = (0, _react.render)(_Options8 || (_Options8 = (0, _jsxRuntime.jsxs)(_index.Options, {
        "data-testId": "outer-list",
        children: [(0, _jsxRuntime.jsx)(_index.Options.Item, {
          children: "Option one "
        }), (0, _jsxRuntime.jsx)(_index.Options.Item, {
          children: "Option two "
        }), (0, _jsxRuntime.jsxs)(_index.Options, {
          renderLabel: 'Nested list',
          "data-testId": "nested-list",
          children: [(0, _jsxRuntime.jsx)(_index.Options.Item, {
            children: "Nested option one "
          }), (0, _jsxRuntime.jsx)(_index.Options.Item, {
            children: "Nested option two "
          })]
        })]
      }))),
      container = _render5.container;
    const allLists = container.querySelectorAll('[class*="-options__list"]');
    const allItems = container.querySelectorAll('[class$="-optionItem"]');
    (0, _vitest.expect)(allLists.length).toBe(2);
    (0, _vitest.expect)(allItems.length).toBe(5);
    const outerList = _react.screen.getByTestId('outer-list');
    (0, _vitest.expect)(outerList).toHaveTextContent('Option one Option two');
    const nestedLabel = outerList.querySelector('[class*=-options__label]');
    (0, _vitest.expect)(nestedLabel).toBeInTheDocument();
    (0, _vitest.expect)(nestedLabel).toHaveTextContent('Nested list');
    const nestedList = _react.screen.getByTestId('nested-list');
    (0, _vitest.expect)(nestedList).toHaveTextContent('Nested option one Nested option two');
    const nestedListItems = nestedList.querySelectorAll('[class$=-optionItem]');
    (0, _vitest.expect)(nestedListItems.length).toBe(2);
    (0, _vitest.expect)(outerList).toContainElement(nestedLabel);
    (0, _vitest.expect)(outerList).toContainElement(nestedList);
  });
  describe('with generated examples', () => {
    const generatedComponents = (0, _generateA11yTests.generateA11yTests)(_index.Options, _Options10.default);
    for (const component of generatedComponents) {
      it(component.description, async () => {
        const _render6 = (0, _react.render)(component.content),
          container = _render6.container;

        // axe-check is more strict now, and expects "list" role to have "listitem" children, but we use "role='none'" children. After discussing it with the A11y team, we agreed to ignore this error because the screen readers can read the component perfectly.
        // TODO: try to remove this ignore if axe-check is updated and isn't this strict anymore
        // https://dequeuniversity.com/rules/axe/4.6/aria-required-children?application=axeAPI
        const axeCheck = await (0, _uiAxeCheck.runAxeCheck)(container, {
          ignores: ['aria-required-children']
        });
        (0, _vitest.expect)(axeCheck).toBe(true);
      });
    }
  });
  describe('for a11y', () => {
    it('should be accessible with links', async () => {
      const _render7 = (0, _react.render)(_Options9 || (_Options9 = (0, _jsxRuntime.jsxs)(_index.Options, {
          children: [(0, _jsxRuntime.jsx)(_index.Options.Item, {
            children: "Option"
          }), (0, _jsxRuntime.jsx)(_index.Options.Item, {
            href: "/",
            children: "Option link"
          })]
        }))),
        container = _render7.container;

      // axe-check is more strict now, and expects "list" role to have "listitem" children, but we use "role='none'" children. After discussing it with the A11y team, we agreed to ignore this error because the screen readers can read the component perfectly.
      // TODO: try to remove this ignore if axe-check is updated and isn't this strict anymore
      // https://dequeuniversity.com/rules/axe/4.6/aria-required-children?application=axeAPI
      const axeCheck = await (0, _uiAxeCheck.runAxeCheck)(container, {
        ignores: ['aria-required-children']
      });
      (0, _vitest.expect)(axeCheck).toBe(true);
    });
  });
});