import type { AsElementType, PropValidators, OptionsItemTheme, OtherHTMLAttributes, Renderable } from '@instructure/shared-types';
import type { WithDeterministicIdProps } from '@instructure/ui-react-utils';
import type { WithStyleProps, ComponentStyle } from '@instructure/emotion';
type OptionsItemRenderProps = {
    children?: Renderable;
    /**
     * Element type to render as. Will be set to `<a>` if href is provided.
     */
    as?: AsElementType;
    /**
     * The style variant of the item
     */
    variant?: 'default' | 'highlighted' | 'selected' | 'disabled' | 'highlighted-disabled' | 'selected-highlighted';
    /**
     * The ARIA role of the element
     */
    role?: string;
};
type OptionsItemOwnProps = OptionsItemRenderProps & {
    /**
     * Content to render before the label
     * (if you pass a function, it has the `props` as its parameter)
     */
    renderBeforeLabel?: Renderable<OptionsItemRenderProps>;
    /**
     * Content to render after the label
     * (if you pass a function, it has the `props` as its parameter)
     */
    renderAfterLabel?: Renderable<OptionsItemRenderProps>;
    /**
     * Sets the vAlign of renderBeforeLabel content
     */
    beforeLabelContentVAlign?: 'start' | 'center' | 'end';
    /**
     * Sets the vAlign of renderAfterLabel content
     */
    afterLabelContentVAlign?: 'start' | 'center' | 'end';
    /**
     * Additional "secondary" description text
     */
    description?: Renderable;
    /**
     * The ARIA role of the description element
     */
    descriptionRole?: string;
    /**
     * Providing href will render the option as `<a>`.
     */
    href?: string;
    /**
     * Sometimes VoiceOver doesn't announce the role of the highlighted item. This prop forces the role to be on the outer element and should only be used when such an issue arises.
     */
    voiceoverRoleBugWorkaround?: boolean;
    /**
     * provides a reference to the underlying html root element
     */
    elementRef?: (element: Element | null) => void;
    /**
     * Whether or not this option is selected
     */
    isSelected?: boolean;
};
type PropKeys = keyof OptionsItemOwnProps;
type AllowedPropKeys = Readonly<Array<PropKeys>>;
type OptionsItemProps = OptionsItemOwnProps & WithStyleProps<OptionsItemTheme, OptionsItemStyle> & WithDeterministicIdProps & OtherHTMLAttributes<OptionsItemOwnProps>;
type OptionsItemStyle = ComponentStyle<'item' | 'container' | 'content' | 'contentBefore' | 'contentAfter' | 'description'>;
declare const propTypes: PropValidators<PropKeys>;
declare const allowedProps: AllowedPropKeys;
export type { OptionsItemProps, OptionsItemStyle, OptionsItemRenderProps };
export { propTypes, allowedProps };
//# sourceMappingURL=props.d.ts.map